@@ -3,7 +3,7 @@
 use serde::{Deserialize, Serialize};
 use serde_encrypt::{
     key::key_pair::{ReceiverKeyPair, SenderKeyPair},
-    serialize::impls::CborSerializer,
+    serialize::impls::BincodeSerializer,
     traits::SerdeEncryptPublicKey,
     EncryptedMessage, Error, ReceiverCombinedKey, ReceiverKeyPairCore, SenderCombinedKey,
     SenderKeyPairCore,
@@ -16,7 +16,7 @@ struct Message {
 }
 
 impl SerdeEncryptPublicKey for Message {
-    type S = CborSerializer<Self>;
+    type S = BincodeSerializer<Self>;
 }
 
 fn alice_sends_secret_message(combined_key: &SenderCombinedKey) -> Result<Vec<u8>, Error> {
