@@ -12,7 +12,10 @@ use serde::{
     Deserialize, Deserializer, Serialize,
 };
 use serde_encrypt::{
-    serialize::{impls::CborSerializer, TypedSerialized},
+    serialize::{
+        impls::{BincodeSerializer, CborSerializer},
+        TypedSerialized,
+    },
     shared_key::SharedKey,
     traits::{SerdeEncryptPublicKey, SerdeEncryptSharedKey},
     AsSharedKey, Error, ErrorKind,
@@ -28,10 +31,10 @@ fn test_unit_struct() -> Result<(), Error> {
     #[derive(PartialEq, Debug, Serialize, Deserialize)]
     struct Unit;
     impl SerdeEncryptPublicKey for Unit {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for Unit {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     let msg = Unit;
@@ -48,10 +51,10 @@ fn test_primitive_type_fixed_len() -> Result<(), Error> {
     #[derive(PartialEq, Debug, Serialize, Deserialize)]
     struct I32(i32);
     impl SerdeEncryptPublicKey for I32 {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for I32 {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     let msg = I32(42);
@@ -68,10 +71,10 @@ fn test_primitive_type_unbound_len() -> Result<(), Error> {
     #[derive(PartialEq, Debug, Serialize, Deserialize)]
     struct MyString(String);
     impl SerdeEncryptPublicKey for MyString {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for MyString {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     let msg = MyString("MyString".to_string());
@@ -88,10 +91,10 @@ fn test_tuple_struct() -> Result<(), Error> {
     #[derive(PartialEq, Debug, Serialize, Deserialize)]
     struct Tuple(i16, i32, i64);
     impl SerdeEncryptPublicKey for Tuple {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for Tuple {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     let msg = Tuple(42, 4242, 424242);
@@ -124,10 +127,10 @@ fn test_enum() -> Result<(), Error> {
         },
     }
     impl SerdeEncryptPublicKey for Message {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for Message {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     let msg_request = Message::Request {
@@ -172,6 +175,8 @@ fn test_enum_tagged() -> Result<(), Error> {
         },
     }
     impl SerdeEncryptPublicKey for Message {
+        // [NG] BincodeSerializer for tagged enum: https://github.com/bincode-org/bincode/issues/272
+        // [NG] PostcardSerializer emits `WontImplement` err: https://github.com/jamesmunns/postcard/blob/96db753865b195948fcbd9c69815028adee9579c/src/de/deserializer.rs#L126
         type S = CborSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for Message {
@@ -220,6 +225,8 @@ fn test_enum_adjacently_tagged() -> Result<(), Error> {
         },
     }
     impl SerdeEncryptPublicKey for Message {
+        // [NG] BincodeSerializer for tagged enum: https://github.com/bincode-org/bincode/issues/272
+        // [NG] PostcardSerializer emits `WontImplement` err: https://github.com/jamesmunns/postcard/blob/96db753865b195948fcbd9c69815028adee9579c/src/de/deserializer.rs#L126
         type S = CborSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for Message {
@@ -268,6 +275,8 @@ fn test_enum_untagged() -> Result<(), Error> {
         },
     }
     impl SerdeEncryptPublicKey for Message {
+        // [NG] BincodeSerializer for tagged enum: https://github.com/bincode-org/bincode/issues/272
+        // [NG] PostcardSerializer emits `WontImplement` err: https://github.com/jamesmunns/postcard/blob/96db753865b195948fcbd9c69815028adee9579c/src/de/deserializer.rs#L126
         type S = CborSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for Message {
@@ -304,10 +313,10 @@ fn test_skip_deserializing() -> Result<(), Error> {
         c: i32,
     }
     impl SerdeEncryptPublicKey for Struct {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for Struct {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     let msg = Struct {
@@ -359,10 +368,10 @@ fn test_skip_deserializing_and_custom_default() -> Result<(), Error> {
         "/".to_string()
     }
     impl SerdeEncryptPublicKey for Request {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for Request {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     /// Timeout in seconds.
@@ -435,6 +444,8 @@ fn test_flatten() -> Result<(), Error> {
         pagination: Pagination,
     }
     impl SerdeEncryptPublicKey for Users {
+        // [NG] BincodeSerializer for #[flatten]: https://github.com/bincode-org/bincode/issues/245
+        // [NG] PostcardSerializer for #[flatten]: https://github.com/jamesmunns/postcard/issues/29
         type S = CborSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for Users {
@@ -470,7 +481,7 @@ fn test_struct_with_reference_shared_key() -> Result<(), Error> {
     #[derive(PartialEq, Debug, Serialize, Deserialize)]
     struct Str<'a>(&'a str);
     impl<'a> SerdeEncryptSharedKey for Str<'a> {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     let msg = Str("Str");
@@ -490,7 +501,7 @@ fn test_struct_with_reference_public_key() -> Result<(), Error> {
     #[derive(PartialEq, Debug, Serialize, Deserialize)]
     struct Str<'a>(&'a str);
     impl<'a> SerdeEncryptPublicKey for Str<'a> {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     let msg = Str("Str");
@@ -519,10 +530,10 @@ fn test_serialize_enum_as_number() -> Result<(), Error> {
         Seven = 7,
     }
     impl SerdeEncryptPublicKey for SmallPrime {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for SmallPrime {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     let msg_two = SmallPrime::Two;
@@ -548,10 +559,10 @@ fn test_serialize_field_as_camel_case() -> Result<(), Error> {
         last_name: String,
     }
     impl SerdeEncryptPublicKey for Person {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for Person {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     let msg = Person {
@@ -575,10 +586,10 @@ fn test_skip_serializing_without_default() -> Result<(), Error> {
         hash: String,
     }
     impl SerdeEncryptPublicKey for Resource {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for Resource {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     let msg_with_metadata = Resource {
@@ -614,10 +625,10 @@ fn test_skip_serializing_if() -> Result<(), Error> {
         metadata: Map<String, String>,
     }
     impl SerdeEncryptPublicKey for Resource {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for Resource {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     let msg_with_metadata = Resource {
@@ -690,10 +701,10 @@ fn test_remote_crate() -> Result<(), Error> {
     }
 
     impl SerdeEncryptPublicKey for Process {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for Process {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     let msg = Process {
@@ -763,10 +774,10 @@ fn test_remote_crate_with_priv_fields() -> Result<(), Error> {
         wall_time: Duration,
     }
     impl SerdeEncryptPublicKey for Process {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for Process {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     let msg = Process {
@@ -837,10 +848,10 @@ fn test_remote_crate_with_helper() -> Result<(), Error> {
         wall_time: Helper,
     }
     impl SerdeEncryptPublicKey for Process {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for Process {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     let msg = Process {
@@ -870,6 +881,8 @@ fn test_string_or_struct() -> Result<(), Error> {
         build: Build,
     }
     impl SerdeEncryptPublicKey for Service {
+        // [NG] BincodeSerializer emits DeserializeAnyNotSupported err
+        // [NG] PostcardSerializer emits `WontImplement` err: https://github.com/jamesmunns/postcard/blob/96db753865b195948fcbd9c69815028adee9579c/src/de/deserializer.rs#L126
         type S = CborSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for Service {
@@ -982,10 +995,10 @@ fn test_convert_error_types() -> Result<(), Error> {
     }
 
     impl SerdeEncryptPublicKey for Resource {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
     impl SerdeEncryptSharedKey for Resource {
-        type S = CborSerializer<Self>;
+        type S = BincodeSerializer<Self>;
     }
 
     #[derive(PartialEq, Debug, Serialize, Deserialize)]
